@@ -1,7 +1,7 @@
 """
 Type annotations for kinesisanalyticsv2 service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/)
 
 Usage::
 
@@ -100,7 +100,7 @@ class Exceptions:
 class KinesisAnalyticsV2Client(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/)
     """
 
     meta: ClientMeta
@@ -111,14 +111,14 @@ class KinesisAnalyticsV2Client(BaseClient):
         KinesisAnalyticsV2Client exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#exceptions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#exceptions)
         """
 
     def add_application_cloud_watch_logging_option(
         self,
         *,
         ApplicationName: str,
-        CloudWatchLoggingOption: "CloudWatchLoggingOptionTypeDef",
+        CloudWatchLoggingOption: CloudWatchLoggingOptionTypeDef,
         CurrentApplicationVersionId: int = ...,
         ConditionalToken: str = ...
     ) -> AddApplicationCloudWatchLoggingOptionResponseTypeDef:
@@ -127,17 +127,17 @@ class KinesisAnalyticsV2Client(BaseClient):
         errors.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_cloud_watch_logging_option)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#add_application_cloud_watch_logging_option)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#add_application_cloud_watch_logging_option)
         """
 
     def add_application_input(
-        self, *, ApplicationName: str, CurrentApplicationVersionId: int, Input: "InputTypeDef"
+        self, *, ApplicationName: str, CurrentApplicationVersionId: int, Input: InputTypeDef
     ) -> AddApplicationInputResponseTypeDef:
         """
         Adds a streaming source to your SQL-based Kinesis Data Analytics application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#add_application_input)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#add_application_input)
         """
 
     def add_application_input_processing_configuration(
@@ -146,25 +146,25 @@ class KinesisAnalyticsV2Client(BaseClient):
         ApplicationName: str,
         CurrentApplicationVersionId: int,
         InputId: str,
-        InputProcessingConfiguration: "InputProcessingConfigurationTypeDef"
+        InputProcessingConfiguration: InputProcessingConfigurationTypeDef
     ) -> AddApplicationInputProcessingConfigurationResponseTypeDef:
         """
         Adds an  InputProcessingConfiguration to a SQL-based Kinesis Data Analytics
         application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input_processing_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#add_application_input_processing_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#add_application_input_processing_configuration)
         """
 
     def add_application_output(
-        self, *, ApplicationName: str, CurrentApplicationVersionId: int, Output: "OutputTypeDef"
+        self, *, ApplicationName: str, CurrentApplicationVersionId: int, Output: OutputTypeDef
     ) -> AddApplicationOutputResponseTypeDef:
         """
         Adds an external destination to your SQL-based Kinesis Data Analytics
         application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_output)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#add_application_output)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#add_application_output)
         """
 
     def add_application_reference_data_source(
@@ -172,21 +172,21 @@ class KinesisAnalyticsV2Client(BaseClient):
         *,
         ApplicationName: str,
         CurrentApplicationVersionId: int,
-        ReferenceDataSource: "ReferenceDataSourceTypeDef"
+        ReferenceDataSource: ReferenceDataSourceTypeDef
     ) -> AddApplicationReferenceDataSourceResponseTypeDef:
         """
         Adds a reference data source to an existing SQL-based Kinesis Data Analytics
         application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_reference_data_source)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#add_application_reference_data_source)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#add_application_reference_data_source)
         """
 
     def add_application_vpc_configuration(
         self,
         *,
         ApplicationName: str,
-        VpcConfiguration: "VpcConfigurationTypeDef",
+        VpcConfiguration: VpcConfigurationTypeDef,
         CurrentApplicationVersionId: int = ...,
         ConditionalToken: str = ...
     ) -> AddApplicationVpcConfigurationResponseTypeDef:
@@ -194,7 +194,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Adds a Virtual Private Cloud (VPC) configuration to the application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_vpc_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#add_application_vpc_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#add_application_vpc_configuration)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -202,7 +202,15 @@ class KinesisAnalyticsV2Client(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#can_paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#can_paginate)
+        """
+
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#close)
         """
 
     def create_application(
@@ -212,16 +220,16 @@ class KinesisAnalyticsV2Client(BaseClient):
         RuntimeEnvironment: RuntimeEnvironmentType,
         ServiceExecutionRole: str,
         ApplicationDescription: str = ...,
-        ApplicationConfiguration: "ApplicationConfigurationTypeDef" = ...,
-        CloudWatchLoggingOptions: Sequence["CloudWatchLoggingOptionTypeDef"] = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        ApplicationConfiguration: ApplicationConfigurationTypeDef = ...,
+        CloudWatchLoggingOptions: Sequence[CloudWatchLoggingOptionTypeDef] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         ApplicationMode: ApplicationModeType = ...
     ) -> CreateApplicationResponseTypeDef:
         """
         Creates a Kinesis Data Analytics application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#create_application)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#create_application)
         """
 
     def create_application_presigned_url(
@@ -236,7 +244,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         extension.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#create_application_presigned_url)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#create_application_presigned_url)
         """
 
     def create_application_snapshot(
@@ -246,7 +254,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Creates a snapshot of the application's state data.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application_snapshot)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#create_application_snapshot)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#create_application_snapshot)
         """
 
     def delete_application(
@@ -256,7 +264,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Deletes the specified application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#delete_application)
         """
 
     def delete_application_cloud_watch_logging_option(
@@ -272,7 +280,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_cloud_watch_logging_option)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application_cloud_watch_logging_option)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#delete_application_cloud_watch_logging_option)
         """
 
     def delete_application_input_processing_configuration(
@@ -282,7 +290,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Deletes an  InputProcessingConfiguration from an input.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_input_processing_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application_input_processing_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#delete_application_input_processing_configuration)
         """
 
     def delete_application_output(
@@ -293,7 +301,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Analytics application's configuration.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_output)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application_output)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#delete_application_output)
         """
 
     def delete_application_reference_data_source(
@@ -304,7 +312,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Kinesis Data Analytics application's configuration.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_reference_data_source)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application_reference_data_source)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#delete_application_reference_data_source)
         """
 
     def delete_application_snapshot(
@@ -318,7 +326,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Deletes a snapshot of application state.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_snapshot)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application_snapshot)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#delete_application_snapshot)
         """
 
     def delete_application_vpc_configuration(
@@ -333,7 +341,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Removes a VPC configuration from a Kinesis Data Analytics application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_vpc_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#delete_application_vpc_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#delete_application_vpc_configuration)
         """
 
     def describe_application(
@@ -343,7 +351,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Returns information about a specific Kinesis Data Analytics application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#describe_application)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#describe_application)
         """
 
     def describe_application_snapshot(
@@ -353,7 +361,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Returns information about a snapshot of application state data.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application_snapshot)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#describe_application_snapshot)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#describe_application_snapshot)
         """
 
     def describe_application_version(
@@ -363,7 +371,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Provides a detailed description of a specified version of the application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application_version)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#describe_application_version)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#describe_application_version)
         """
 
     def discover_input_schema(
@@ -371,9 +379,9 @@ class KinesisAnalyticsV2Client(BaseClient):
         *,
         ServiceExecutionRole: str,
         ResourceARN: str = ...,
-        InputStartingPositionConfiguration: "InputStartingPositionConfigurationTypeDef" = ...,
-        S3Configuration: "S3ConfigurationTypeDef" = ...,
-        InputProcessingConfiguration: "InputProcessingConfigurationTypeDef" = ...
+        InputStartingPositionConfiguration: InputStartingPositionConfigurationTypeDef = ...,
+        S3Configuration: S3ConfigurationTypeDef = ...,
+        InputProcessingConfiguration: InputProcessingConfigurationTypeDef = ...
     ) -> DiscoverInputSchemaResponseTypeDef:
         """
         Infers a schema for a SQL-based Kinesis Data Analytics application by evaluating
@@ -381,7 +389,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Data Firehose delivery stream) or Amazon S3 object.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.discover_input_schema)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#discover_input_schema)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#discover_input_schema)
         """
 
     def generate_presigned_url(
@@ -395,7 +403,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#generate_presigned_url)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#generate_presigned_url)
         """
 
     def list_application_snapshots(
@@ -405,7 +413,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Lists information about the current application snapshots.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_application_snapshots)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#list_application_snapshots)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#list_application_snapshots)
         """
 
     def list_application_versions(
@@ -416,7 +424,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         were rolled back.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_application_versions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#list_application_versions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#list_application_versions)
         """
 
     def list_applications(
@@ -426,7 +434,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Returns a list of Kinesis Data Analytics applications in your account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_applications)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#list_applications)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#list_applications)
         """
 
     def list_tags_for_resource(self, *, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
@@ -434,7 +442,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Retrieves the list of key-value tags assigned to the application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#list_tags_for_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#list_tags_for_resource)
         """
 
     def rollback_application(
@@ -444,17 +452,17 @@ class KinesisAnalyticsV2Client(BaseClient):
         Reverts the application to the previous running version.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.rollback_application)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#rollback_application)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#rollback_application)
         """
 
     def start_application(
-        self, *, ApplicationName: str, RunConfiguration: "RunConfigurationTypeDef" = ...
+        self, *, ApplicationName: str, RunConfiguration: RunConfigurationTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Starts the specified Kinesis Data Analytics application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.start_application)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#start_application)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#start_application)
         """
 
     def stop_application(self, *, ApplicationName: str, Force: bool = ...) -> Dict[str, Any]:
@@ -462,15 +470,15 @@ class KinesisAnalyticsV2Client(BaseClient):
         Stops the application from processing data.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.stop_application)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#stop_application)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#stop_application)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Adds one or more key-value tags to a Kinesis Data Analytics application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.tag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#tag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#tag_resource)
         """
 
     def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
@@ -478,7 +486,7 @@ class KinesisAnalyticsV2Client(BaseClient):
         Removes one or more tags from a Kinesis Data Analytics application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.untag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#untag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#untag_resource)
         """
 
     def update_application(
@@ -486,30 +494,30 @@ class KinesisAnalyticsV2Client(BaseClient):
         *,
         ApplicationName: str,
         CurrentApplicationVersionId: int = ...,
-        ApplicationConfigurationUpdate: "ApplicationConfigurationUpdateTypeDef" = ...,
+        ApplicationConfigurationUpdate: ApplicationConfigurationUpdateTypeDef = ...,
         ServiceExecutionRoleUpdate: str = ...,
-        RunConfigurationUpdate: "RunConfigurationUpdateTypeDef" = ...,
-        CloudWatchLoggingOptionUpdates: Sequence["CloudWatchLoggingOptionUpdateTypeDef"] = ...,
+        RunConfigurationUpdate: RunConfigurationUpdateTypeDef = ...,
+        CloudWatchLoggingOptionUpdates: Sequence[CloudWatchLoggingOptionUpdateTypeDef] = ...,
         ConditionalToken: str = ...
     ) -> UpdateApplicationResponseTypeDef:
         """
         Updates an existing Kinesis Data Analytics application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.update_application)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#update_application)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#update_application)
         """
 
     def update_application_maintenance_configuration(
         self,
         *,
         ApplicationName: str,
-        ApplicationMaintenanceConfigurationUpdate: "ApplicationMaintenanceConfigurationUpdateTypeDef"
+        ApplicationMaintenanceConfigurationUpdate: ApplicationMaintenanceConfigurationUpdateTypeDef
     ) -> UpdateApplicationMaintenanceConfigurationResponseTypeDef:
         """
         Updates the maintenance configuration of the Kinesis Data Analytics application.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.update_application_maintenance_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#update_application_maintenance_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#update_application_maintenance_configuration)
         """
 
     @overload
@@ -518,7 +526,7 @@ class KinesisAnalyticsV2Client(BaseClient):
     ) -> ListApplicationSnapshotsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#get_paginator)
         """
 
     @overload
@@ -527,5 +535,5 @@ class KinesisAnalyticsV2Client(BaseClient):
     ) -> ListApplicationsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/client/#get_paginator)
         """
